@@ -1,22 +1,9 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2001-2004 George Staikos <staikos@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2001-2004 George Staikos <staikos@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kwalletbackend.h"
 #include "kwalletbackend_debug.h"
@@ -35,8 +22,8 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QSaveFile>
-#include <QRegExp>
 #include <QCryptographicHash>
+#include <QRegularExpression>
 #include <QStandardPaths>
 
 #include "blowfish.h"
@@ -70,8 +57,6 @@ class Backend::BackendPrivate
 Backend::Backend(const QString &name, bool isPath)
     : d(nullptr),
       _name(name),
-      _useNewHash(false),
-      _ref(0),
       _cipherType(KWallet::BACKEND_CIPHER_UNKNOWN)
 {
 //  initKWalletDir();
@@ -94,7 +79,7 @@ Backend::~Backend()
 
 QString Backend::getSaveLocation()
 {
-    QString writeLocation = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+    QString writeLocation = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
     if (writeLocation.right(1) == QLatin1String("5")) {
       // HACK
       // setApplicationName("kwalletd5") yields the path ~/.local/share/kwalletd5 for the location where to store wallets
@@ -457,7 +442,7 @@ int Backend::sync(WId w)
         // Oops! wallet file sync filed! Display a notification about that
         // TODO: change kwalletd status flags, when status flags will be implemented
         KNotification *notification = new KNotification(QStringLiteral("syncFailed"));
-        notification->setText(i18n("Failed to sync wallet <b>%1</b> to disk. Error codes are:\nRC <b>%2</b>\nSF <b>%3</b>. Please file a BUG report using this information to bugs.kde.org").arg(_name).arg(rc).arg(sf.errorString()));
+        notification->setText(i18n("Failed to sync wallet <b>%1</b> to disk. Error codes are:\nRC <b>%2</b>\nSF <b>%3</b>. Please file a BUG report using this information to bugs.kde.org", _name, rc, sf.errorString()));
         notification->sendEvent();
     }
     delete phandler;
@@ -522,6 +507,7 @@ Entry *Backend::readEntry(const QString &key)
     return rc;
 }
 
+#if KWALLET_BUILD_DEPRECATED_SINCE(5, 72)
 QList<Entry *> Backend::readEntryList(const QString &key)
 {
     QList<Entry *> rc;
@@ -530,16 +516,31 @@ QList<Entry *> Backend::readEntryList(const QString &key)
         return rc;
     }
 
-    const QRegExp re(key, Qt::CaseSensitive, QRegExp::Wildcard);
+    // HACK: see Wallet::WalletPrivate::forEachItemThatMatches()
+    const QString pattern = QRegularExpression::wildcardToRegularExpression(key).replace(
+                                                         QLatin1String("[^/]"), QLatin1String("."));
+    const QRegularExpression re(pattern);
 
     const EntryMap &map = _entries[_folder];
     for (EntryMap::ConstIterator i = map.begin(); i != map.end(); ++i) {
-        if (re.exactMatch(i.key())) {
+        if (re.match(i.key()).hasMatch()) {
             rc.append(i.value());
         }
     }
     return rc;
 }
+#endif
+
+QList<Entry *> Backend::entriesList() const
+{
+    if (!_open) {
+        return QList<Entry *>();
+    }
+    const EntryMap &map = _entries[_folder];
+
+    return map.values();
+}
+
 
 bool Backend::createFolder(const QString &f)
 {
