@@ -1,43 +1,27 @@
-/**
-  * This file is part of the KDE project
-  * Copyright (C) 2013 Valentin Rusu <kde@rusu.info>
-  *
-  * This library is free software; you can redistribute it and/or
-  * modify it under the terms of the GNU Library General Public
-  * License version 2 as published by the Free Software Foundation.
-  *
-  * This library is distributed in the hope that it will be useful,
-  * but WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * Library General Public License for more details.
-  *
-  * You should have received a copy of the GNU Library General Public License
-  * along with this library; see the file COPYING.LIB.  If not, write to
-  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2013 Valentin Rusu <kde@rusu.info>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "knewwalletdialog.h"
 #include "kwalletd_debug.h"
-#include <klocalizedstring.h>
-#include <QLabel>
-#include <QTextDocument>
-#include <QTimer>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <QTableWidget>
 #include <QTableWidgetItem>
-#include <gpgme.h>
 #include <gpgme++/context.h>
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
-#include <kmessagebox.h>
+#include <gpgme.h>
 
 Q_DECLARE_METATYPE(GpgME::Key)
 
 namespace KWallet
 {
-
-KNewWalletDialog::KNewWalletDialog(const QString &appName, const QString &walletName, QWidget *parent):
-    QWizard(parent)
+KNewWalletDialog::KNewWalletDialog(const QString &appName, const QString &walletName, QWidget *parent)
+    : QWizard(parent)
 {
     setOption(HaveFinishButtonOnEarlyPages);
     _intro = new KNewWalletDialogIntro(appName, walletName, this);
@@ -55,16 +39,24 @@ bool KNewWalletDialog::isBlowfish() const
 GpgME::Key KNewWalletDialog::gpgKey() const
 {
     QVariant varKey = field(QStringLiteral("key"));
-    return varKey.value< GpgME::Key >();
+    return varKey.value<GpgME::Key>();
 }
 
-KNewWalletDialogIntro::KNewWalletDialogIntro(const QString &appName, const QString &walletName, QWidget *parent): QWizardPage(parent)
+KNewWalletDialogIntro::KNewWalletDialogIntro(const QString &appName, const QString &walletName, QWidget *parent)
+    : QWizardPage(parent)
 {
     _ui.setupUi(this);
     if (appName.isEmpty()) {
-        _ui.labelIntro->setText(i18n("<qt>KDE has requested to create a new wallet named '<b>%1</b>'. This is used to store sensitive data in a secure fashion. Please choose the new wallet's type below or click cancel to deny the application's request.</qt>", walletName.toHtmlEscaped()));
+        _ui.labelIntro->setText(
+            i18n("<qt>KDE has requested to create a new wallet named '<b>%1</b>'. This is used to store sensitive data in a secure fashion. Please choose the "
+                 "new wallet's type below or click cancel to deny the application's request.</qt>",
+                 walletName.toHtmlEscaped()));
     } else {
-        _ui.labelIntro->setText(i18n("<qt>The application '<b>%1</b>' has requested to create a new wallet named '<b>%2</b>'. This is used to store sensitive data in a secure fashion. Please choose the new wallet's type below or click cancel to deny the application's request.</qt>", appName.toHtmlEscaped(), walletName.toHtmlEscaped()));
+        _ui.labelIntro->setText(
+            i18n("<qt>The application '<b>%1</b>' has requested to create a new wallet named '<b>%2</b>'. This is used to store sensitive data in a secure "
+                 "fashion. Please choose the new wallet's type below or click cancel to deny the application's request.</qt>",
+                 appName.toHtmlEscaped(),
+                 walletName.toHtmlEscaped()));
     }
 }
 
@@ -83,12 +75,14 @@ int KNewWalletDialogIntro::nextId() const
     if (isBlowfish()) {
         return -1;
     } else {
-        return qobject_cast< const KNewWalletDialog * >(wizard())->gpgId();
+        return qobject_cast<const KNewWalletDialog *>(wizard())->gpgId();
     }
 }
 
-KNewWalletDialogGpg::KNewWalletDialogGpg(const QString &appName, const QString &walletName, QWidget *parent):
-    QWizardPage(parent), _alreadyInitialized(false), _complete(false)
+KNewWalletDialogGpg::KNewWalletDialogGpg(const QString &appName, const QString &walletName, QWidget *parent)
+    : QWizardPage(parent)
+    , _alreadyInitialized(false)
+    , _complete(false)
 {
     _ui.setupUi(this);
 }
@@ -96,7 +90,11 @@ KNewWalletDialogGpg::KNewWalletDialogGpg(const QString &appName, const QString &
 struct AddKeyToList {
     QTableWidget *_list;
     int _row;
-    AddKeyToList(QTableWidget *list) : _list(list), _row(0) {}
+    AddKeyToList(QTableWidget *list)
+        : _list(list)
+        , _row(0)
+    {
+    }
     void operator()(const GpgME::Key &k)
     {
         GpgME::UserID uid = k.userID(0);
@@ -126,19 +124,21 @@ void KNewWalletDialogGpg::initializePage()
     GpgME::Error err = GpgME::checkEngine(GpgME::OpenPGP);
     if (err) {
         qCDebug(KWALLETD_LOG) << "OpenPGP not supported on your system!";
-        KMessageBox::error(this, i18n("The GpgME library failed to initialize for the OpenPGP protocol. Please check your system's configuration then try again."));
-        emit completeChanged();
+        KMessageBox::error(this,
+                           i18n("The GpgME library failed to initialize for the OpenPGP protocol. Please check your system's configuration then try again."));
+        Q_EMIT completeChanged();
         return;
     }
-    std::shared_ptr< GpgME::Context >   _ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
+    std::shared_ptr<GpgME::Context> _ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
     if (!_ctx) {
-        KMessageBox::error(this, i18n("The GpgME library failed to initialize for the OpenPGP protocol. Please check your system's configuration then try again."));
-        emit completeChanged();
+        KMessageBox::error(this,
+                           i18n("The GpgME library failed to initialize for the OpenPGP protocol. Please check your system's configuration then try again."));
+        Q_EMIT completeChanged();
         return;
     }
     _ctx->setKeyListMode(GpgME::Local);
 
-    std::vector< GpgME::Key > keys;
+    std::vector<GpgME::Key> keys;
     err = _ctx->startKeyListing();
     while (!err) {
         GpgME::Key k = _ctx->nextKey(err);
@@ -152,8 +152,9 @@ void KNewWalletDialogGpg::initializePage()
     _ctx->endKeyListing();
 
     if (keys.size() == 0) {
-        KMessageBox::error(this, i18n("Seems that your system has no keys suitable for encryption. Please set-up at least one encryption key, then try again."));
-        emit completeChanged();
+        KMessageBox::error(this,
+                           i18n("Seems that your system has no keys suitable for encryption. Please set-up at least one encryption key, then try again."));
+        Q_EMIT completeChanged();
         return;
     }
 
@@ -170,7 +171,7 @@ void KNewWalletDialogGpg::onItemSelectionChanged()
     _complete = _ui.listCertificates->currentRow() >= 0;
     QVariant varKey = _ui.listCertificates->item(_ui.listCertificates->currentRow(), 0)->data(Qt::UserRole);
     setField(QStringLiteral("key"), varKey);
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 bool KNewWalletDialogGpg::isComplete() const
